@@ -2,10 +2,12 @@ from . import openapi
 from . import scrape
 from . import cv
 from . import nlp
+from . import line
 
 __all__ = [
     'openapi',
     'scrape',
     'cv',
-    'nlp'
+    'nlp',
+    'line'
 ]
\ No newline at end of file
